package com.ruoyi.dz.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.dz.mapper.DzSelectSubjectMapper;
import com.ruoyi.dz.domain.DzSelectSubject;
import com.ruoyi.dz.service.IDzSelectSubjectService;

/**
 * 科目组合Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-09-27
 */
@Service
public class DzSelectSubjectServiceImpl implements IDzSelectSubjectService 
{
    @Autowired
    private DzSelectSubjectMapper dzSelectSubjectMapper;

    /**
     * 查询科目组合
     * 
     * @param groupId 科目组合主键
     * @return 科目组合
     */
    @Override
    public DzSelectSubject selectDzSelectSubjectByGroupId(String groupId)
    {
        return dzSelectSubjectMapper.selectDzSelectSubjectByGroupId(groupId);
    }

    /**
     * 查询科目组合列表
     * 
     * @param dzSelectSubject 科目组合
     * @return 科目组合
     */
    @Override
    public List<DzSelectSubject> selectDzSelectSubjectList(DzSelectSubject dzSelectSubject)
    {
        return dzSelectSubjectMapper.selectDzSelectSubjectList(dzSelectSubject);
    }

    /**
     * 新增科目组合
     * 
     * @param dzSelectSubject 科目组合
     * @return 结果
     */
    @Override
    public int insertDzSelectSubject(DzSelectSubject dzSelectSubject)
    {
        return dzSelectSubjectMapper.insertDzSelectSubject(dzSelectSubject);
    }

    /**
     * 修改科目组合
     * 
     * @param dzSelectSubject 科目组合
     * @return 结果
     */
    @Override
    public int updateDzSelectSubject(DzSelectSubject dzSelectSubject)
    {
        return dzSelectSubjectMapper.updateDzSelectSubject(dzSelectSubject);
    }

    /**
     * 批量删除科目组合
     * 
     * @param groupIds 需要删除的科目组合主键
     * @return 结果
     */
    @Override
    public int deleteDzSelectSubjectByGroupIds(String[] groupIds)
    {
        return dzSelectSubjectMapper.deleteDzSelectSubjectByGroupIds(groupIds);
    }

    /**
     * 删除科目组合信息
     * 
     * @param groupId 科目组合主键
     * @return 结果
     */
    @Override
    public int deleteDzSelectSubjectByGroupId(String groupId)
    {
        return dzSelectSubjectMapper.deleteDzSelectSubjectByGroupId(groupId);
    }
}
